Crate openweathermap

Modules

Structs

  • Detailed clouds report
  • Location coordinates
  • current weather report in a nested struct
  • Detailed weather report
  • Additional information
  • Rain or snow volume report
  • Weather condition description
  • Detailed wind report

Constants

  • Loading error messaage you get at the first call of update().

Functions

  • Spawns a thread which fetches the current weather from openweathermap.org periodically.
  • Get current weather update that the spawned thread could fetched.
  • Fetch current weather update once and stop thread immediately after success. Returns the result in a future.

Type Aliases

  • Receiver object you get from init() and have top handle to update().